@@ -4,9 +4,6 @@ import * as vscode from "vscode";
 import * as cp from "child_process";
 import * as util from "util";
 
-// TODO: JS build system should read rust-toolchain.toml and fill this in automatically
-const TOOLCHAIN = "nightly";
-
 const exec = util.promisify(cp.exec);
 
 let channel = vscode.window.createOutputChannel("Flowistry");
@@ -30,9 +27,7 @@ interface SliceOutput {
 export async function activate(context: vscode.ExtensionContext) {
   log("flowistry is activated");
 
-  let { stdout } = await exec(
-    `$(rustup which --toolchain ${TOOLCHAIN} rustc) --print target-libdir`
-  );
+  let { stdout } = await exec("rustc --print target-libdir");
   let lib_dir = stdout.trim();
   log("Rustc target-libdir", lib_dir);
 
@@ -49,7 +44,10 @@ export async function activate(context: vscode.ExtensionContext) {
   let workspace_root = folders[0].uri.fsPath;
   log("Workspace root", workspace_root);
 
-  let slice = async (forward: boolean) => {
+  let slice = async (
+    direction: "backward" | "forward",
+    type: "highlight" | "select"
+  ) => {
     let active_editor = vscode.window.activeTextEditor;
     if (!active_editor) {
       return;
@@ -63,7 +61,7 @@ export async function activate(context: vscode.ExtensionContext) {
       DYLD_LIBRARY_PATH: lib_dir,
       LD_LIBRARY_PATH: lib_dir,
     };
-    let subcmd = forward ? "forward_slice" : "backward_slice";
+    let subcmd = `${direction}_slice`;
     let cmd = `cargo flowistry ${subcmd} ${doc.fileName} ${doc.offsetAt(
       selection.start
     )} ${doc.offsetAt(selection.end)}`;
@@ -79,7 +77,7 @@ export async function activate(context: vscode.ExtensionContext) {
       let last_line = lines[lines.length - 1];
       let slice_output: SliceOutput = JSON.parse(last_line);
 
-      let decorations = slice_output.ranges.map(
+      let ranges = slice_output.ranges.map(
         (slice_range: any) =>
           new vscode.Range(
             doc.positionAt(slice_range.start),
@@ -87,7 +85,7 @@ export async function activate(context: vscode.ExtensionContext) {
           )
       );
 
-      if (decorations.length === 0) {
+      if (ranges.length === 0) {
         let selected_text = active_editor.document.getText(selection);
         vscode.window.showInformationMessage(
           `Slice on "${selected_text}" did not generate any results`
@@ -95,18 +93,24 @@ export async function activate(context: vscode.ExtensionContext) {
         return;
       }
 
-      active_editor.setDecorations(decoration_type, decorations);
+      if (type === "select") {
+        active_editor.selections = ranges.map(
+          (range) => new vscode.Selection(range.start, range.end)
+        );
+      } else {
+        active_editor.setDecorations(decoration_type, ranges);
 
-      let callback = vscode.workspace.onDidChangeTextDocument((event) => {
-        if (!active_editor) {
-          return;
-        }
-        if (event.document !== active_editor.document) {
-          return;
-        }
-        active_editor.setDecorations(decoration_type, []);
-        callback.dispose();
-      });
+        let callback = vscode.workspace.onDidChangeTextDocument((event) => {
+          if (!active_editor) {
+            return;
+          }
+          if (event.document !== active_editor.document) {
+            return;
+          }
+          active_editor.setDecorations(decoration_type, []);
+          callback.dispose();
+        });
+      }
     } catch (exc) {
       log("ERROR", exc);
       vscode.window.showErrorMessage(`Flowistry failed with error: ${exc}`);
@@ -117,15 +121,16 @@ export async function activate(context: vscode.ExtensionContext) {
   // Now provide the implementation of the command with registerCommand
   // The commandId parameter must match the command field in package.json
 
-  let register_with_opts = (name: string, forward: boolean) => {
-    let disposable = vscode.commands.registerCommand(`flowistry.${name}`, () =>
-      slice(forward)
-    );
+  let register_with_opts = (name: string, f: () => void) => {
+    let disposable = vscode.commands.registerCommand(`flowistry.${name}`, f);
     context.subscriptions.push(disposable);
   };
 
-  register_with_opts("backward_slice", false);
-  register_with_opts("forward_slice", true);
+  ["backward", "forward"].forEach((direction: any) => {
+    ["highlight", "select"].forEach((type: any) => {
+      register_with_opts(`${direction}_${type}`, () => slice(direction, type));
+    });
+  });
 }
 
 export function deactivate() {}
